@@ -7,6 +7,6 @@ Pattern mining algorithms for the Python ecosystem
 # see : https://github.com/joblib/joblib/issues/634#issuecomment-367321025
 # joblib currently disable logging inside delayed functions
 __author__ = """scikit-mine team"""
-__email__ = """remi.adon@gmail.com"""
-__version__ = "0.0.8"  # pylint: disable= undefined-variable, pointless-statement
-__credits__ = "Centre Inria Rennes - Bretagne Atlantique"
+__email__ = """skm-dev@inria.fr"""
+__version__ = "0.0.9"  # pylint: disable= undefined-variable, pointless-statement
+__credits__ = "Centre Inria de l'Université de Rennes"
