@@ -11,7 +11,7 @@ def get_data_home(data_home=None):
     This folder is used by some large dataset loaders to avoid downloading
     data several times.
 
-    By default ``data_home`` is **$HOME/scikit_mine_data/**
+    By default, ``data_home`` is **./scikit_mine_data/**
 
     Alternatively, it can be set by the **SCIKIT_MINE_DATA** environment
     variable or programmatically by giving an explicit folder path.
@@ -21,10 +21,12 @@ def get_data_home(data_home=None):
     data_home : str | None
         The path to scikit-mine data dir.
     """
+    import skmine
+    sk_path = skmine.__file__  # example sk_path = '/home/username/codes/sk_root/skmine/__init__.py'
+    sk_root = os.path.dirname(os.path.dirname(sk_path))  # sk_root = '/home/username/codes/sk_root
+
     if data_home is None:
-        data_home = os.environ.get(
-            "SCIKIT_MINE_DATA", os.path.join("~", "scikit_mine_data")
-        )
+        data_home = os.environ.get("SCIKIT_MINE_DATA", os.path.join(sk_root, "scikit_mine_data"))
     data_home = os.path.expanduser(data_home)
     if not os.path.exists(data_home):
         os.makedirs(data_home)
